@@ -16,7 +16,7 @@
 #' @return Returns a RasterStack object.
 #' @examples
 #' \dontrun{
-#' files <- find_smap(id = "SPL4SMGP", dates = "2015-03-31", version = 3)
+#' files <- find_smap(id = "SPL4SMGP", dates = "2015-03-31", version = 4)
 #' downloads <- download_smap(files[1, ])
 #' sm_raster <- extract_smap(downloads, name = '/Geophysical_Data/sm_surface')
 #' }
@@ -119,7 +119,8 @@ is_cube <- function(array) {
 find_fill_value <- function(file, name) {
     data_attributes <- h5readAttributes(file, name)
     if ("_FillValue" %in% names(data_attributes)) {
-        fill_value <- data_attributes$`_FillValue`
+        # extract first element to ensure this is not an array
+        fill_value <- data_attributes$`_FillValue`[1]
     } else {
         fill_value <- -9999
     }
