@@ -2,13 +2,13 @@ context("download_smap")
 
 test_that("invalid output directories cause errors", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
+    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 5)
     expect_error(download_smap(files[1, ], dir = 1234))
 })
 
 test_that("non-existent directories are created", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
+    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 5)
     dir_name <- "silly_nonexistent_directory"
     downloads <- download_smap(files, directory = dir_name)
     expect_true(dir.exists(dir_name))
@@ -20,26 +20,26 @@ test_that("valid user-specified directories contain downloads", {
     skip_on_cran()
     available_data <- find_smap(id = "SPL3SMP",
                                 date = "2015-10-01",
-                                version = 4)
+                                version = 5)
     user_specified_path <- file.path('data', 'SMAP')
     downloads <- download_smap(available_data,
                                directory = user_specified_path)
     expect_true(
         file.exists(
             file.path(user_specified_path,
-                      "SMAP_L3_SM_P_20151001_R14010_001.h5")
+                      "SMAP_L3_SM_P_20151001_R16010_001.h5")
             )
         )
     expect_true(
         file.exists(
             file.path(user_specified_path,
-                      "SMAP_L3_SM_P_20151001_R14010_001.h5.iso.xml")
+                      "SMAP_L3_SM_P_20151001_R16010_001.h5.iso.xml")
         )
     )
     expect_true(
         file.exists(
             file.path(user_specified_path,
-                      "SMAP_L3_SM_P_20151001_R14010_001.qa")
+                      "SMAP_L3_SM_P_20151001_R16010_001.qa")
         )
     )
 
@@ -49,14 +49,14 @@ test_that("valid user-specified directories contain downloads", {
 
 test_that("the downloaded data is of the data frame class", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
+    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 5)
     downloads <- download_smap(files[1, ])
     expect_that(downloads, is_a("data.frame"))
 })
 
 test_that("Two SPL4CMDL data files are downloaded (h5 and xml)", {
     skip_on_cran()
-    files <- find_smap(id = "SPL4CMDL", dates = "2015-05-01", version = 3)
+    files <- find_smap(id = "SPL4CMDL", dates = "2015-05-01", version = 4)
     downloads <- download_smap(files[1, ])
     file_prefix <- downloads$name
     downloaded_files <- list.files(downloads$local_dir)
@@ -78,7 +78,7 @@ test_that("setting overwrite = FALSE prevents data from being overwritten", {
         as.numeric(time)
     }
 
-    files <- find_smap(id = "SPL3SMP", date = "2015-03-31", version = 4)
+    files <- find_smap(id = "SPL3SMP", date = "2015-03-31", version = 5)
 
     downloads <- download_smap(files)
     modified1 <- get_last_modified(downloads)
@@ -100,7 +100,7 @@ test_that("setting overwrite = TRUE ensures data overwrite", {
         as.numeric(time)
     }
 
-    files <- find_smap(id = "SPL3SMP", date = "2015-03-31", version = 4)
+    files <- find_smap(id = "SPL3SMP", date = "2015-03-31", version = 5)
 
     downloads <- download_smap(files, overwrite = TRUE)
     modified1 <- get_last_modified(downloads)
@@ -110,7 +110,7 @@ test_that("setting overwrite = TRUE ensures data overwrite", {
     downloads <- download_smap(files, overwrite = TRUE)
     modified2 <- get_last_modified(downloads)
 
-    expect_gt(modified2, modified1)
+    expect_gt(modified2[1], modified1[1])
 })
 
 
@@ -124,12 +124,12 @@ test_that('input data.frames with NA values raise errors', {
 
 test_that('verbose = TRUE prints output', {
   skip_on_cran()
-  files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
+  files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 5)
   downloads <- expect_message(download_smap(files[1, ], verbose = TRUE))
 })
 
 test_that('verbose = FALSE suppresses output', {
   skip_on_cran()
-  files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
+  files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 5)
   downloads <- expect_silent(download_smap(files[1, ], verbose = FALSE))
 })
